@@ -1,11 +1,12 @@
 # coding: utf-8
 
-# PYTHON IMPORTS
 import os
 import shutil
 
-# DJANGO IMPORTS
 from django.core.files.move import file_move_safe
+from django.utils.encoding import smart_str
+from filebrowser.base import FileObject
+from filebrowser.settings import DEFAULT_PERMISSIONS
 
 
 class StorageMixin(object):
@@ -45,6 +46,12 @@ class StorageMixin(object):
         """
         raise NotImplementedError()
 
+    def setpermission(self, name):
+        """
+        Sets file permission
+        """
+        raise NotImplementedError()
+
 
 class FileSystemStorageMixin(StorageMixin):
 
@@ -63,6 +70,10 @@ class FileSystemStorageMixin(StorageMixin):
     def rmtree(self, name):
         shutil.rmtree(self.path(name))
 
+    def setpermission(self, name):
+        full_path = FileObject(smart_str(name), site=self).path_full
+        os.chmod(full_path, DEFAULT_PERMISSIONS)
+
 
 class S3BotoStorageMixin(StorageMixin):
 
@@ -113,3 +124,9 @@ class S3BotoStorageMixin(StorageMixin):
         dirlist = self.bucket.list(self._encode_name(name))
         for item in dirlist:
             item.delete()
+
+    def setpermission(self, name):
+        # Permissions for S3 uploads with django-storages
+        # is set in settings.py with AWS_DEFAULT_ACL.
+        # More info: http://django-common-configs.readthedocs.org/en/latest/configs/storage.html
+        pass
